```{include} ../README.md
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: Getting Started

installation
guides/quickstart
acknowledgements
contributing
changelog
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: Toolbox Introductions

guides/fac/intro_fac
guides/dsecs/intro_dsecs
guides/tfa/intro_tfa
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: TFA Toolbox

guides/tfa/tfa_background
guides/tfa/tfa_MAGx_LR
guides/tfa/tfa_MAGx_HR
guides/tfa/tfa_EFIx_TCT
guides/tfa/tfa_AUX_OBS
guides/tfa/tfa_Cluster
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: For developers

guides/shared/paldata
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: API

api/io
api/fac
api/dsecs
api/tfa
```
